@@ -4,6 +4,7 @@ from collections import OrderedDict
 import warnings
 import logging
 from joblib import dump
+from sklearn import pipeline
 
 from Accuinsight.modeler.core import func, path, get
 from Accuinsight.modeler.core.func import get_time
@@ -86,8 +87,11 @@ class accuinsight(Common):
         def __init__(self, model_name, *args, model_monitor=False):
             self.shap_on = model_monitor
             logging.info('Using add_experiment(model_monitor={})'.format(model_monitor))
-            
-            self.model_name = model_name
+
+            if type(self.model_name) == pipeline.Pipeline:
+                self.model_name = model_name.steps[-1][1]
+            else:
+                self.model_name = model_name
         
             # if in notebook
             if is_in_ipython():
@@ -229,9 +233,6 @@ class accuinsight(Common):
                 with open(shap_json_full_path, 'w', encoding = 'utf-8') as save_file:
                     json.dump(self.shap_value, save_file, indent='\t')
                 
-            else:
-                pass
-                
             # visualization
             if any(i in self.fitted_model for i in CLASSIFICATION) or self.all_model_params['metric'] in metricsLightgbm.CLASSIFICATION:
 
