@@ -1,7 +1,7 @@
 import datetime, json
 
 from Accuinsight.modeler.entities.monitoring_deploy_log import DeployLog
-from Accuinsight.modeler.entities.monitoring_deploy_alarm import DeployAlarm
+from Accuinsight.modeler.entities.alarm import Alarm
 from Accuinsight.modeler.clients.modeler_api import DeployLogRestApi
 from Accuinsight.modeler.core.MonitoringConst.deploy import DeployConst
 from Accuinsight.modeler.utils.os_getenv import get_os_env
@@ -16,7 +16,7 @@ class AddDeployLog:
         env_value = get_os_env('ENV')
 
         self.deploy_log = DeployLog()
-        self.deploy_alarm = DeployAlarm()
+        self.deploy_alarm = Alarm()
         self.deploy_log_api = DeployLogRestApi(env_value[DeployConst.BACK_END_API_URL],
                                                env_value[DeployConst.BACK_END_API_PORT],
                                                env_value[DeployConst.BACK_END_API_URI])
@@ -66,19 +66,21 @@ class AddDeployLog:
 
         try:
             self.deploy_log.response_data = json.loads(res_data)
-        except json.decoder.JSONDecodeError:
+        except (json.decoder.JSONDecodeError, UnicodeDecodeError):
             self.deploy_log.response_data = str(res_data)
 
-    def add_log(self, messages, notifiers):
+    def set_slack(self, hook_url):
+        if hook_url:
+            self.deploy_alarm.notifiers['slack'] = hook_url
+
+    def set_mail(self, address):
+        if address:
+            self.deploy_alarm.notifiers['mail'] = address
+
+    def add_log(self, messages):
         if not self.swagger:
-            if messages is not None:
-                self.deploy_alarm.timestamp = datetime.datetime.now().timestamp()
-
-                if 'slack' in notifiers.keys():
-                    self.deploy_alarm.notifiers['slack'] = notifiers['slack']['hook_url']
-
-                if 'mail' in notifiers.keys():
-                    self.deploy_alarm.notifiers['mail'] = notifiers['mail']['address']
+            if messages:
+                self.deploy_alarm.type = "DeployAPI"
 
                 for message in messages:
                     self.deploy_alarm.message = message
