@@ -162,7 +162,10 @@ def _make_parameter_data(json_body):
     # metrics_object = {'key': '', 'values': [], 'timestamp': [], 'steps': []}
 
     # get metrics
-    parameter_data = json_body['parameter']
+    try:
+        parameter_data = json_body['parameter']
+    except KeyError:
+        parameter_data = []
     # "parameter": {
     #     "parameter": {
     #       "learningrate": "0.12",
